summaryrefslogtreecommitdiff
path: root/firmware/2lib/include/2return_codes.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/2lib/include/2return_codes.h')
-rw-r--r--firmware/2lib/include/2return_codes.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/firmware/2lib/include/2return_codes.h b/firmware/2lib/include/2return_codes.h
index 27b80d16..d03b0739 100644
--- a/firmware/2lib/include/2return_codes.h
+++ b/firmware/2lib/include/2return_codes.h
@@ -161,16 +161,16 @@ enum vb2_return_code {
/* Member data outside parent in vb2_verify_member_inside() */
VB2_ERROR_INSIDE_DATA_OUTSIDE,
/* Unsupported signature algorithm in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_SIG_ALGORITHM, /* 0x150008 */
/* Bad key size in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_SIZE,
/* Bad key alignment in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_ALIGN,
/* Bad key array size in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_ARRAY_SIZE,
/* Bad algorithm in vb2_verify_data() */
@@ -194,7 +194,7 @@ enum vb2_return_code {
*/
VB2_ERROR_VDATA_DIGEST_SIZE,
/* Unsupported hash algorithm in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_HASH_ALGORITHM,
/* Member data overlaps member header */
@@ -256,9 +256,12 @@ enum vb2_return_code {
/* Key algorithm doesn't match signature algorithm */
VB2_ERROR_VDATA_ALGORITHM_MISMATCH,
/* Bad magic number in vb2_unpack_key() */
VB2_ERROR_UNPACK_KEY_MAGIC,
+ /* Null public key buffer passed to vb2_unpack_key_buffer() */
+ VB2_ERROR_UNPACK_KEY_BUFFER,
+
/**********************************************************************
* Keyblock verification errors (all in vb2_verify_keyblock())
*/
@@ -161,16 +161,16 @@ enum vb2_return_code {
/* Member data outside parent in vb2_verify_member_inside() */
VB2_ERROR_INSIDE_DATA_OUTSIDE,
- /* Unsupported signature algorithm in vb2_unpack_key() */
+ /* Unsupported signature algorithm in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_SIG_ALGORITHM, /* 0x150008 */
@@ -161,16 +161,16 @@ enum vb2_return_code {
VB2_ERROR_UNPACK_KEY_SIG_ALGORITHM, /* 0x150008 */
- /* Bad key size in vb2_unpack_key() */
+ /* Bad key size in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_SIZE,
@@ -161,16 +161,16 @@ enum vb2_return_code {
VB2_ERROR_UNPACK_KEY_SIZE,
- /* Bad key alignment in vb2_unpack_key() */
+ /* Bad key alignment in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_ALIGN,
@@ -161,16 +161,16 @@ enum vb2_return_code {
VB2_ERROR_UNPACK_KEY_ALIGN,
- /* Bad key array size in vb2_unpack_key() */
+ /* Bad key array size in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_ARRAY_SIZE,
/* Bad algorithm in vb2_verify_data() */
@@ -194,7 +194,7 @@ enum vb2_return_code {
*/
VB2_ERROR_VDATA_DIGEST_SIZE,
- /* Unsupported hash algorithm in vb2_unpack_key() */
+ /* Unsupported hash algorithm in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_HASH_ALGORITHM,
/* Member data overlaps member header */
@@ -256,9 +256,12 @@ enum vb2_return_code {
/* Key algorithm doesn't match signature algorithm */
VB2_ERROR_VDATA_ALGORITHM_MISMATCH,
- /* Bad magic number in vb2_unpack_key() */
+ /* Bad magic number in vb2_unpack_key_buffer() */
VB2_ERROR_UNPACK_KEY_MAGIC,